==> lyrics_transcriber-0.37.0-py3-none-any.whl: lyrics_transcriber/review/server.py <==
import logging
from fastapi import FastAPI, Body
from fastapi.middleware.cors import CORSMiddleware
from typing import Optional, Dict, Any
from ..types import CorrectionResult, WordCorrection, LyricsSegment
import time
import subprocess
import os
import atexit
import urllib.parse
from fastapi.staticfiles import StaticFiles
from fastapi.responses import FileResponse
from pathlib import Path
import socket

logger = logging.getLogger(__name__)

app = FastAPI()

# Configure CORS for development
app.add_middleware(
    CORSMiddleware,
    allow_origins=[f"http://localhost:{port}" for port in range(3000, 5174)]  # Common development ports
    + [f"http://127.0.0.1:{port}" for port in range(3000, 5174)],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Global state for the review process
current_review: Optional[CorrectionResult] = None
review_completed = False
vite_process: Optional[subprocess.Popen] = None
audio_filepath: Optional[str] = None  # Add this new global variable


def start_vite_server():
    """Get path to the built frontend assets."""
    global vite_process  # We'll keep this for backwards compatibility

    # Get the path to the built frontend assets
    current_dir = os.path.dirname(os.path.abspath(__file__))
    frontend_dir = os.path.abspath(os.path.join(current_dir, "../frontend/dist"))

    if not os.path.exists(frontend_dir):
        raise FileNotFoundError(f"Frontend assets not found at {frontend_dir}. Ensure the package was built correctly.")

    # Mount the static files
    app.mount("/", StaticFiles(directory=frontend_dir, html=True), name="frontend")

    logger.info(f"Mounted frontend assets from {frontend_dir}")
    return None  # No process to return since we're serving static files


@app.get("/api/correction-data")
async def get_correction_data():
    """Get the current correction data for review."""
    if current_review is None:
        return {"error": "No review in progress"}
    return current_review.to_dict()


@app.post("/api/complete")
async def complete_review(updated_data: Dict[str, Any] = Body(...)):
    """
    Mark the review as complete and update the correction data.

    Args:
        updated_data: Dictionary containing corrections and corrected_segments
    """
    global review_completed, current_review

    logger.info("Received updated correction data")

    try:
        # Only update the specific fields that were modified
        if current_review is None:
            raise ValueError("No review in progress")

        # Update only the corrections and corrected_segments
        current_review.corrections = [WordCorrection.from_dict(c) for c in updated_data["corrections"]]
        current_review.corrected_segments = [LyricsSegment.from_dict(s) for s in updated_data["corrected_segments"]]
        current_review.corrections_made = len(current_review.corrections)

        logger.info(f"Successfully updated correction data with {len(current_review.corrections)} corrections")

        review_completed = True
        return {"status": "success"}
    except Exception as e:
        logger.error(f"Failed to update correction data: {str(e)}")
        return {"status": "error", "message": str(e)}


@app.get("/api/audio")
async def get_audio():
    """Stream the audio file for playback in the browser."""
    if not audio_filepath or not os.path.exists(audio_filepath):
        logger.error(f"Audio file not found at {audio_filepath}")
        return {"error": "Audio file not found"}

    return FileResponse(
        audio_filepath,
        media_type="audio/mpeg",
        headers={"Accept-Ranges": "bytes", "Content-Disposition": f"attachment; filename={Path(audio_filepath).name}"},
    )


def start_review_server(correction_result: CorrectionResult) -> CorrectionResult:
    """
    Start the review server and wait for completion.

    Args:
        correction_result: The correction result to review

    Returns:
        The potentially modified correction result after review
    """
    import uvicorn
    import webbrowser
    from threading import Thread
    import signal
    import sys

    global current_review, review_completed, audio_filepath
    current_review = correction_result
    review_completed = False

    audio_filepath = correction_result.metadata.get("audio_filepath") if correction_result.metadata else None

    logger.info("Starting review server...")

    # Start Vite dev server (now just mounts static files)
    start_vite_server()
    logger.info("Frontend assets mounted")

    # Find an available port starting from 8000
    port = 8000
    while True:
        try:
            # Test if port is available
            with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
                s.bind(("127.0.0.1", port))
                break
        except OSError:
            port += 1
            if port > 8100:  # Set a reasonable upper limit
                raise RuntimeError("Unable to find an available port")

    logger.info(f"Using port {port}")

    # Create a custom server config with the found port
    config = uvicorn.Config(app, host="127.0.0.1", port=port, log_level="info")
    server = uvicorn.Server(config)

    # Start FastAPI server in a separate thread
    server_thread = Thread(target=server.run, daemon=True)
    server_thread.start()
    logger.info("Server thread started")

    # Open browser with the correct port
    base_api_url = f"http://localhost:{port}/api"
    encoded_api_url = urllib.parse.quote(base_api_url, safe="")
    webbrowser.open(f"http://localhost:{port}?baseApiUrl={encoded_api_url}")
    logger.info("Opened browser for review")

    # Wait for review to complete
    start_time = time.time()
    while not review_completed:
        time.sleep(0.1)

    logger.info("Review completed, shutting down server...")
    server.should_exit = True
    server_thread.join(timeout=5)  # Wait up to 5 seconds for server to shut down

    return current_review

==> lyrics_transcriber-0.40.0-py3-none-any.whl: lyrics_transcriber/review/server.py <==
import logging
from fastapi import FastAPI, Body
from fastapi.middleware.cors import CORSMiddleware
from typing import Optional, Dict, Any
from ..types import CorrectionResult, WordCorrection, LyricsSegment
import time
import subprocess
import os
import atexit
import urllib.parse
from fastapi.staticfiles import StaticFiles
from fastapi.responses import FileResponse
from pathlib import Path
import socket

logger = logging.getLogger(__name__)

app = FastAPI()

# Configure CORS for development
app.add_middleware(
    CORSMiddleware,
    allow_origins=[f"http://localhost:{port}" for port in range(3000, 5174)]  # Common development ports
    + [f"http://127.0.0.1:{port}" for port in range(3000, 5174)],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Global state for the review process
current_review: Optional[CorrectionResult] = None
review_completed = False
vite_process: Optional[subprocess.Popen] = None
audio_filepath: Optional[str] = None  # Add this new global variable


def start_vite_server():
    """Get path to the built frontend assets."""
    global vite_process  # We'll keep this for backwards compatibility

    # Get the path to the built frontend assets
    current_dir = os.path.dirname(os.path.abspath(__file__))
    frontend_dir = os.path.abspath(os.path.join(current_dir, "../frontend/dist"))

    if not os.path.exists(frontend_dir):
        raise FileNotFoundError(f"Frontend assets not found at {frontend_dir}. Ensure the package was built correctly.")

    # Mount the static files
    app.mount("/", StaticFiles(directory=frontend_dir, html=True), name="frontend")

    logger.info(f"Mounted frontend assets from {frontend_dir}")
    return None  # No process to return since we're serving static files


@app.get("/api/correction-data")
async def get_correction_data():
    """Get the current correction data for review."""
    if current_review is None:
        return {"error": "No review in progress"}
    return current_review.to_dict()


@app.post("/api/complete")
async def complete_review(updated_data: Dict[str, Any] = Body(...)):
    """
    Mark the review as complete and update the correction data.

    Args:
        updated_data: Dictionary containing corrections and corrected_segments
    """
    global review_completed, current_review

    logger.info("Received updated correction data")

    try:
        # Only update the specific fields that were modified
        if current_review is None:
            raise ValueError("No review in progress")

        # Update only the corrections and corrected_segments
        current_review.corrections = [WordCorrection.from_dict(c) for c in updated_data["corrections"]]
        current_review.corrected_segments = [LyricsSegment.from_dict(s) for s in updated_data["corrected_segments"]]
        current_review.corrections_made = len(current_review.corrections)

        logger.info(f"Successfully updated correction data with {len(current_review.corrections)} corrections")

        review_completed = True
        return {"status": "success"}
    except Exception as e:
        logger.error(f"Failed to update correction data: {str(e)}")
        return {"status": "error", "message": str(e)}


@app.get("/api/audio")
async def get_audio():
    """Stream the audio file for playback in the browser."""
    if not audio_filepath or not os.path.exists(audio_filepath):
        logger.error(f"Audio file not found at {audio_filepath}")
        return {"error": "Audio file not found"}

    return FileResponse(
        audio_filepath,
        media_type="audio/mpeg",
        headers={"Accept-Ranges": "bytes", "Content-Disposition": f"attachment; filename={Path(audio_filepath).name}"},
    )


def start_review_server(correction_result: CorrectionResult) -> CorrectionResult:
    """
    Start the review server and wait for completion.

    Args:
        correction_result: The correction result to review

    Returns:
        The potentially modified correction result after review
    """
    import uvicorn
    import webbrowser
    from threading import Thread
    import signal
    import sys

    global current_review, review_completed, audio_filepath
    current_review = correction_result
    review_completed = False

    audio_filepath = correction_result.metadata.get("audio_filepath") if correction_result.metadata else None

    logger.info("Starting review server...")

    # Start Vite dev server (now just mounts static files)
    start_vite_server()
    logger.info("Frontend assets mounted")

    # Wait for default port (8000) to become available
    DEFAULT_PORT = 8000
    while True:
        try:
            with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
                s.bind(("127.0.0.1", DEFAULT_PORT))
                break
        except OSError:
            logger.info(f"Port {DEFAULT_PORT} is occupied, waiting 10 seconds before retrying...")
            time.sleep(10)

    logger.info(f"Port {DEFAULT_PORT} is available, starting server")

    # Create server config with default port
    config = uvicorn.Config(app, host="127.0.0.1", port=DEFAULT_PORT, log_level="info")
    server = uvicorn.Server(config)

    # Start FastAPI server in a separate thread
    server_thread = Thread(target=server.run, daemon=True)
    server_thread.start()
    logger.info("Server thread started")

    # Open browser with the correct port
    base_api_url = f"http://localhost:{DEFAULT_PORT}/api"
    encoded_api_url = urllib.parse.quote(base_api_url, safe="")
    webbrowser.open(f"http://localhost:{DEFAULT_PORT}?baseApiUrl={encoded_api_url}")
    logger.info("Opened browser for review")

    # Wait for review to complete
    start_time = time.time()
    while not review_completed:
        time.sleep(0.1)

    logger.info("Review completed, shutting down server...")
    server.should_exit = True
    server_thread.join(timeout=5)  # Wait up to 5 seconds for server to shut down

    return current_review
